# Implemented Grammar in GlyLES

## Implemented Monomers

All following derivatives of root monomers are implemented in alpha, beta and undefined conformation of the C1 atom.

* Gal
  * Gal3S
  * Gal3S4S
  * Gal3S6S
  * Gal4S
  * Gal4S6S
  * Gal6S
  * GalNAc
  * GalNAc3S
  * GalNAc4S
  * GalNAc4S6S
  * GalNAc6S
* Glc
  * Glc4S
  * Glc6S
  * GlcA
  * GlcN
  * GlcNAc
  * GlcNAc3S
  * GlcNAc6S
* Neu
  * Neu5Ac (currently disabled)
  * Neu5Gc (currently disables)
